@@ -22,7 +22,6 @@ import android.app.Activity;
 import android.graphics.Bitmap;
 import android.graphics.drawable.Drawable;
 import android.text.format.DateUtils;
-import android.util.Log;
 import android.view.LayoutInflater;
 import android.view.View;
 import android.view.ViewGroup;
@@ -31,18 +30,9 @@ import android.widget.ImageView;
 import android.widget.ListView;
 import android.widget.RelativeLayout;
 import android.widget.TextView;
-
 import androidx.annotation.NonNull;
 import androidx.appcompat.content.res.AppCompatResources;
 import androidx.core.content.ContextCompat;
-
-import org.apache.commons.lang3.StringUtils;
-
-import java.text.NumberFormat;
-import java.time.Duration;
-import java.time.Instant;
-import java.util.List;
-
 import edu.berkeley.boinc.BOINCActivity;
 import edu.berkeley.boinc.ProjectsFragment.ProjectsListData;
 import edu.berkeley.boinc.R;
@@ -50,6 +40,12 @@ import edu.berkeley.boinc.rpc.Notice;
 import edu.berkeley.boinc.rpc.Transfer;
 import edu.berkeley.boinc.rpc.TransferStatus;
 import edu.berkeley.boinc.utils.Logging;
+import java.text.DecimalFormat;
+import java.text.NumberFormat;
+import java.time.Duration;
+import java.time.Instant;
+import java.util.List;
+import org.apache.commons.lang3.StringUtils;
 
 public class ProjectsListAdapter extends ArrayAdapter<ProjectsListData> {
     private List<ProjectsListData> entries;
@@ -78,6 +74,12 @@ public class ProjectsListAdapter extends ArrayAdapter<ProjectsListData> {
         return position;
     }
 
+    public String getDiskUsage(int position) {
+        double diskUsage = entries.get(position).getProject().getDiskUsage();
+        DecimalFormat df = new DecimalFormat("#.##");
+        return df.format(diskUsage/(1024*1024));
+    }
+
     public String getName(int position) {
         return entries.get(position).getProject().getProjectName();
     }
@@ -99,7 +101,7 @@ public class ProjectsListAdapter extends ArrayAdapter<ProjectsListData> {
             return BOINCActivity.monitor.getProjectIcon(entries.get(position).id);
         }
         catch(Exception e) {
-            Log.w(Logging.TAG, "ProjectsListAdapter: Could not load data, clientStatus not initialized.");
+            Logging.logException(Logging.Category.MONITOR, "ProjectsListAdapter: Could not load data, clientStatus not initialized.", e);
 
             return null;
         }
@@ -173,7 +175,7 @@ public class ProjectsListAdapter extends ArrayAdapter<ProjectsListData> {
                 statusText = BOINCActivity.monitor.getProjectStatus(data.getProject().getMasterURL());
             }
             catch(Exception e) {
-                Log.e(Logging.TAG, "ProjectsListAdapter.getView error: ", e);
+                Logging.logException(Logging.Category.GUI_VIEW, "ProjectsListAdapter.getView error: ", e);
             }
             TextView tvStatus = vi.findViewById(R.id.project_status);
             if(statusText.isEmpty()) {
@@ -292,6 +294,10 @@ public class ProjectsListAdapter extends ArrayAdapter<ProjectsListData> {
                                                                        NumberFormat.getIntegerInstance().format(hostCredit) :
                                                                        this.activity.getString(R.string.projects_credits_host_and_user, hostCredit, userCredit));
 
+            TextView tvDiskUsage = vi.findViewById(R.id.project_disk_usage);
+            String diskUsage = getDiskUsage(position);
+            tvDiskUsage.setText(this.activity.getString(R.string.projects_disk_usage_with_unit, diskUsage));
+
             // server notice
             Notice notice = data.getLastServerNotice();
             TextView tvNotice = vi.findViewById(R.id.project_notice);
