@@ -19,15 +19,13 @@
 
 package edu.berkeley.boinc.attach;
 
-import edu.berkeley.boinc.R;
-import edu.berkeley.boinc.utils.*;
-
 import android.os.Bundle;
-import androidx.fragment.app.Fragment;
-import android.util.Log;
 import android.view.LayoutInflater;
 import android.view.View;
 import android.view.ViewGroup;
+import androidx.fragment.app.Fragment;
+import edu.berkeley.boinc.R;
+import edu.berkeley.boinc.utils.Logging;
 
 public class HintFragment extends Fragment {
 
@@ -44,7 +42,7 @@ public class HintFragment extends Fragment {
 
     @Override
     public View onCreateView(LayoutInflater inflater, ViewGroup container, Bundle savedInstanceState) {
-        Log.d(Logging.TAG, "HintFragment onCreateView for hint type: " + type);
+        Logging.logVerbose(Logging.Category.GUI_VIEW, "HintFragment onCreateView for hint type: " + type);
 
         View v = null;
         switch(type) {
