@@ -18,7 +18,6 @@
  */
 package edu.berkeley.boinc.rpc
 
-import android.util.Log
 import android.util.Xml
 import edu.berkeley.boinc.utils.Logging
 import org.xml.sax.Attributes
@@ -58,7 +57,7 @@ class AccountOutParser : BaseParser() {
                 }
             }
         } catch (e: NumberFormatException) {
-            Log.e(Logging.TAG, "AccountOutParser.endElement error: ", e)
+            Logging.logException(Logging.Category.XML, "AccountOutParser.endElement error: ", e)
         }
         mElementStarted = false
     }
@@ -80,8 +79,8 @@ class AccountOutParser : BaseParser() {
                 Xml.parse(outResult, parser)
                 parser.accountOut
             } catch (e: SAXException) {
-                Log.e(Logging.TAG, "AccountOutParser: malformed XML ", e)
-                Log.d(Logging.TAG, "AccountOutParser: $rpcResult")
+                Logging.logException(Logging.Category.RPC, "AccountOutParser: malformed XML ", e)
+                Logging.logDebug(Logging.Category.XML, "AccountOutParser: $rpcResult")
                 
                 null
             }
