@@ -31,10 +31,12 @@ CONFIG_LDFLAGS=""
 
 if [ $BUILD_WITH_VCPKG = "yes" ]; then
     CONFIG_LDFLAGS="-L$VCPKG_DIR/lib"
-    CONFIG_FLAGS="--with-libcurl=$VCPKG_DIR --with-ssl=$VCPKG_DIR --enable-vcpkg"
+    CONFIG_FLAGS="--with-ssl=$VCPKG_DIR --with-libcurl=$VCPKG_DIR"
+    export _libcurl_pc="$VCPKG_DIR/lib/pkgconfig/libcurl.pc"
 else
-    CONFIG_FLAGS="--with-ssl=$TCINCLUDES"
+    CONFIG_FLAGS="--with-ssl=$TCINCLUDES --with-libcurl=$TCINCLUDES"
     CONFIG_LDFLAGS="-L$TCSYSROOT/usr/lib -L$TCINCLUDES/lib"
+    export _libcurl_pc="$TCINCLUDES/lib/pkgconfig/libcurl.pc"
 fi
 
 export PATH="$TCBINARIES:$TCINCLUDES/bin:$PATH"
