@@ -212,12 +212,14 @@ CUDA_GDG p_cuDeviceGet = NULL;
 CUDA_GDA p_cuDeviceGetAttribute = NULL;
 CUDA_GDN p_cuDeviceGetName = NULL;
 CUDA_GDM p_cuDeviceTotalMem = NULL;
+CUDA_GDM p_cuDeviceTotalMem_v2 = NULL;
 CUDA_GDCC p_cuDeviceComputeCapability = NULL;
 CUDA_CC p_cuCtxCreate = NULL;
 CUDA_CD p_cuCtxDestroy = NULL;
 CUDA_MA p_cuMemAlloc = NULL;
 CUDA_MF p_cuMemFree = NULL;
 CUDA_MGI p_cuMemGetInfo = NULL;
+CUDA_MGI p_cuMemGetInfo_v2 = NULL;
 #else
 int (*p_cuInit)(unsigned int);
 int (*p_cuDeviceGetCount)(int*);
@@ -226,12 +228,14 @@ int (*p_cuDeviceGet)(int*, int);
 int (*p_cuDeviceGetAttribute)(int*, int, int);
 int (*p_cuDeviceGetName)(char*, int, int);
 int (*p_cuDeviceTotalMem)(size_t*, int);
+int (*p_cuDeviceTotalMem_v2)(size_t*, int);
 int (*p_cuDeviceComputeCapability)(int*, int*, int);
 int (*p_cuCtxCreate)(void**, unsigned int, unsigned int);
 int (*p_cuCtxDestroy)(void*);
 int (*p_cuMemAlloc)(unsigned int*, size_t);
 int (*p_cuMemFree)(unsigned int);
 int (*p_cuMemGetInfo)(size_t*, size_t*);
+int (*p_cuMemGetInfo_v2)(size_t*, size_t*);
 #endif
 
 // NVIDIA interfaces are documented here:
@@ -241,7 +245,7 @@ void COPROC_NVIDIA::get(
     vector<string>& warnings
 ) {
     int cuda_ndevs, retval;
-    char buf[256];
+    char buf[2048];
     int j, itemp;
     size_t global_mem = 0;
     string s;
@@ -260,12 +264,14 @@ void COPROC_NVIDIA::get(
     p_cuDeviceGetAttribute = (CUDA_GDA)GetProcAddress( cudalib, "cuDeviceGetAttribute" );
     p_cuDeviceGetName = (CUDA_GDN)GetProcAddress( cudalib, "cuDeviceGetName" );
     p_cuDeviceTotalMem = (CUDA_GDM)GetProcAddress( cudalib, "cuDeviceTotalMem" );
+    p_cuDeviceTotalMem_v2 = (CUDA_GDM)GetProcAddress(cudalib, "cuDeviceTotalMem_v2");
     p_cuDeviceComputeCapability = (CUDA_GDCC)GetProcAddress( cudalib, "cuDeviceComputeCapability" );
     p_cuCtxCreate = (CUDA_CC)GetProcAddress( cudalib, "cuCtxCreate" );
     p_cuCtxDestroy = (CUDA_CD)GetProcAddress( cudalib, "cuCtxDestroy" );
     p_cuMemAlloc = (CUDA_MA)GetProcAddress( cudalib, "cuMemAlloc" );
     p_cuMemFree = (CUDA_MF)GetProcAddress( cudalib, "cuMemFree" );
-    p_cuMemGetInfo = (CUDA_MGI)GetProcAddress( cudalib, "cuMemGetInfo" );
+    p_cuMemGetInfo = (CUDA_MGI)GetProcAddress(cudalib, "cuMemGetInfo");
+    p_cuMemGetInfo_v2 = (CUDA_MGI)GetProcAddress(cudalib, "cuMemGetInfo_v2");
 
 #ifndef SIM
     NvAPI_Initialize();
@@ -309,12 +315,14 @@ void* cudalib = NULL;
     p_cuDeviceGetAttribute = (int(*)(int*, int, int)) dlsym( cudalib, "cuDeviceGetAttribute" );
     p_cuDeviceGetName = (int(*)(char*, int, int)) dlsym( cudalib, "cuDeviceGetName" );
     p_cuDeviceTotalMem = (int(*)(size_t*, int)) dlsym( cudalib, "cuDeviceTotalMem" );
+    p_cuDeviceTotalMem_v2 = (int(*)(size_t*, int)) dlsym(cudalib, "cuDeviceTotalMem_v2");
     p_cuDeviceComputeCapability = (int(*)(int*, int*, int)) dlsym( cudalib, "cuDeviceComputeCapability" );
     p_cuCtxCreate = (int(*)(void**, unsigned int, unsigned int)) dlsym( cudalib, "cuCtxCreate" );
     p_cuCtxDestroy = (int(*)(void*)) dlsym( cudalib, "cuCtxDestroy" );
     p_cuMemAlloc = (int(*)(unsigned int*, size_t)) dlsym( cudalib, "cuMemAlloc" );
     p_cuMemFree = (int(*)(unsigned int)) dlsym( cudalib, "cuMemFree" );
     p_cuMemGetInfo = (int(*)(size_t*, size_t*)) dlsym( cudalib, "cuMemGetInfo" );
+    p_cuMemGetInfo_v2 = (int(*)(size_t*, size_t*)) dlsym(cudalib, "cuMemGetInfo_v2");
 #endif
 
     if (!p_cuDriverGetVersion) {
@@ -337,7 +345,7 @@ void* cudalib = NULL;
         warnings.push_back("cuDeviceGetAttribute() missing from NVIDIA library");
         goto leave;
     }
-    if (!p_cuDeviceTotalMem) {
+    if (!p_cuDeviceTotalMem && !p_cuDeviceTotalMem_v2) {
         warnings.push_back("cuDeviceTotalMem() missing from NVIDIA library");
         goto leave;
     }
@@ -409,7 +417,11 @@ void* cudalib = NULL;
             goto leave;
         }
         (*p_cuDeviceComputeCapability)(&cc.prop.major, &cc.prop.minor, device);
-        (*p_cuDeviceTotalMem)(&global_mem, device);
+        if (p_cuDeviceTotalMem_v2) {
+            (*p_cuDeviceTotalMem_v2)(&global_mem, device);
+        } else {
+            (*p_cuDeviceTotalMem)(&global_mem, device);
+        }
         cc.prop.totalGlobalMem = (double) global_mem;
         (*p_cuDeviceGetAttribute)(&itemp, CU_DEVICE_ATTRIBUTE_SHARED_MEMORY_PER_BLOCK, device);
         cc.prop.sharedMemPerBlock = (double) itemp;
@@ -564,7 +576,7 @@ static void get_available_nvidia_ram(COPROC_NVIDIA &cc, vector<string>& warnings
         warnings.push_back("cuCtxDestroy() missing from NVIDIA library");
         return;
     }
-    if (!p_cuMemGetInfo) {
+    if (!p_cuMemGetInfo && !p_cuMemGetInfo_v2) {
         warnings.push_back("cuMemGetInfo() missing from NVIDIA library");
         return;
     }
@@ -585,7 +597,12 @@ static void get_available_nvidia_ram(COPROC_NVIDIA &cc, vector<string>& warnings
         warnings.push_back(buf);
         return;
     }
-    retval = (*p_cuMemGetInfo)(&memfree, &memtotal);
+    if (p_cuMemGetInfo_v2) {
+        retval = (*p_cuMemGetInfo_v2)(&memfree, &memtotal);
+    }
+    else {
+        retval = (*p_cuMemGetInfo)(&memfree, &memtotal);
+    }
     if (retval) {
         snprintf(buf, sizeof(buf),
             "[coproc] cuMemGetInfo(%d) returned %d", cc.device_num, retval
