@@ -1,6 +1,6 @@
 // This file is part of BOINC.
 // http://boinc.berkeley.edu
-// Copyright (C) 2020 University of California
+// Copyright (C) 2022 University of California
 //
 // BOINC is free software; you can redistribute it and/or modify it
 // under the terms of the GNU Lesser General Public License
@@ -107,7 +107,7 @@ CSimpleFrame::CSimpleFrame() {
 }
 
 
-CSimpleFrame::CSimpleFrame(wxString title, wxIconBundle* icons, wxPoint position, wxSize size) : 
+CSimpleFrame::CSimpleFrame(wxString title, wxIconBundle* icons, wxPoint position, wxSize size) :
     CBOINCBaseFrame((wxFrame *)NULL, ID_SIMPLEFRAME, title, position, size,
         wxMINIMIZE_BOX | wxSYSTEM_MENU | wxCAPTION | wxCLOSE_BOX | wxCLIP_CHILDREN
     )
@@ -118,6 +118,9 @@ CSimpleFrame::CSimpleFrame(wxString title, wxIconBundle* icons, wxPoint position
     CreateMenus();
     dlgMsgsPtr = NULL;
     m_pBackgroundPanel = new CSimpleGUIPanel(this);
+    mainSizer = new wxBoxSizer(wxVERTICAL);
+    mainSizer->Add(m_pBackgroundPanel, 1, wxLEFT | wxRIGHT | wxEXPAND, 0);
+    SetSizerAndFit(mainSizer);
     RestoreState();
 }
 
@@ -127,7 +130,7 @@ bool CSimpleFrame::CreateMenus() {
     wxString           strMenuDescription;
     bool               is_acct_mgr_detected = false;
     CMainDocument*     pDoc = wxGetApp().GetDocument();
-    
+
     CSkinAdvanced*     pSkinAdvanced = wxGetApp().GetSkinManager()->GetAdvanced();
 
     wxASSERT(pDoc);
@@ -142,7 +145,7 @@ bool CSimpleFrame::CreateMenus() {
     wxMenu *menuFile = new wxMenu;
 
     strMenuDescription.Printf(
-        _("Close the %s window"), 
+        _("Close the %s window"),
         pSkinAdvanced->GetApplicationName().c_str()
     );
     strMenuName = _("&Close window");
@@ -179,12 +182,12 @@ bool CSimpleFrame::CreateMenus() {
 
     // Skins submenu
     m_pSubmenuSkins = new wxMenu;
-    
+
     BuildSkinSubmenu(m_pSubmenuSkins);
-    
-    // All other skin names will be appended as radio 
+
+    // All other skin names will be appended as radio
     // menu items with ID_SGFIRSTSKINSELECTOR + index
-    
+
     // View menu
     wxMenu *menuView = new wxMenu;
 
@@ -216,9 +219,9 @@ bool CSimpleFrame::CreateMenus() {
         _("Computing &preferences..."),
         _("Configure computing preferences")
     );
-    
+
     menuOptions->Append(
-        ID_SGOPTIONS, 
+        ID_SGOPTIONS,
         _("&Other options..."),
         _("Configure display options and proxy settings")
     );
@@ -267,7 +270,7 @@ bool CSimpleFrame::CreateMenus() {
     }
     menuTools->AppendSeparator();
     menuTools->Append(
-        ID_EVENTLOG, 
+        ID_EVENTLOG,
         _("Event Log...\tCtrl+Shift+E"),
         _("Display diagnostic messages.")
     );
@@ -276,35 +279,35 @@ bool CSimpleFrame::CreateMenus() {
     wxMenu *menuHelp = new wxMenu;
 
     strMenuName.Printf(
-        _("%s &help"), 
+        _("%s &help"),
         pSkinAdvanced->GetApplicationShortName().c_str()
     );
     strMenuDescription.Printf(
-        _("Show information about %s"), 
+        _("Show information about %s"),
         pSkinAdvanced->GetApplicationShortName().c_str()
     );
     menuHelp->Append(
         ID_HELPBOINC,
-        strMenuName, 
+        strMenuName,
         strMenuDescription
     );
 
     strMenuName.Printf(
-        _("&%s help"), 
+        _("&%s help"),
         pSkinAdvanced->GetApplicationHelpName().c_str()
     );
     strMenuDescription.Printf(
-        _("Show information about the %s"), 
+        _("Show information about the %s"),
         pSkinAdvanced->GetApplicationHelpName().c_str()
     );
     menuHelp->Append(
         ID_HELPBOINCMANAGER,
-        strMenuName, 
+        strMenuName,
         strMenuDescription
     );
     menuHelp->AppendSeparator();
     strMenuName.Printf(
-        _("%s &web site"), 
+        _("%s &web site"),
         pSkinAdvanced->GetApplicationShortName().c_str()
     );
     strMenuDescription.Printf(
@@ -313,7 +316,7 @@ bool CSimpleFrame::CreateMenus() {
     );
     menuHelp->Append(
         ID_HELPBOINCWEBSITE,
-        strMenuName, 
+        strMenuName,
         strMenuDescription
     );
     menuHelp->AppendSeparator();
@@ -341,12 +344,12 @@ bool CSimpleFrame::CreateMenus() {
     menuHelp->AppendSeparator();
 
     strMenuName.Printf(
-        _("&About %s..."), 
+        _("&About %s..."),
         pSkinAdvanced->GetApplicationName().c_str()
     );
     menuHelp->Append(
         wxID_ABOUT,
-        strMenuName, 
+        strMenuName,
         _("Licensing and copyright information.")
     );
 
@@ -372,7 +375,7 @@ bool CSimpleFrame::CreateMenus() {
         menuHelp,
         _("&Help")
     );
-    
+
     wxMenuBar* m_pOldMenubar = GetMenuBar();
     SetMenuBar(m_pMenubar);
     if (m_pOldMenubar) {
@@ -404,7 +407,7 @@ CSimpleFrame::~CSimpleFrame() {
     wxLogTrace(wxT("Function Start/End"), wxT("CSimpleFrame::CSimpleFrame - Destructor Function Begin"));
 
     SaveState();
-    
+
     if (m_pAccelTable)
         delete m_pAccelTable;
 
@@ -467,20 +470,22 @@ void CSimpleFrame::OnMenuOpening( wxMenuEvent &event) {
     wxMenu* menuFile = NULL;
     wxMenu* menuHelp = NULL;
     wxMenu* menuChangeGUI = NULL;
-    
+    wxMenu* menuSkinSelector = NULL;
+
     wxASSERT(pDoc);
-    
+
     bool isConnected = pDoc->IsConnected();
     wxMenu* menu = event.GetMenu();
     if (!menu) return;
-    
+
     menu->FindItem(ID_CLOSEWINDOW, &menuFile);
     menu->FindItem(ID_HELPBOINC, &menuHelp);
     menu->FindItem(ID_CHANGEGUI, &menuChangeGUI);
+    menu->FindItem(ID_SGDEFAULTSKINSELECTOR, &menuSkinSelector);
     size_t numItems = menu->GetMenuItemCount();
     for (size_t pos = 0; pos < numItems; ++pos) {
         wxMenuItem * item = menu->FindItemByPosition(pos);
-        if ((menu == menuFile) || (menu == menuHelp) || (menu == menuChangeGUI)) {
+        if ((menu == menuFile) || (menu == menuHelp) || (menu == menuChangeGUI) || (menu == menuSkinSelector)) {
             // Always enable all items in File menu or Help menu:
             // ID_CLOSEWINDOW, wxID_EXIT, ID_HELPBOINC, ID_HELPBOINCMANAGER,
             // ID_HELPBOINCWEBSITE, wxID_ABOUT, ID_CHANGEGUI
@@ -492,7 +497,7 @@ void CSimpleFrame::OnMenuOpening( wxMenuEvent &event) {
             }
         }
     }
-    
+
     // wxID_EXIT and wxID_PREFERENCES are not in File menu on some platforms
     wxMenuItem* exitItem = menu->FindChildItem(wxID_EXIT, NULL);
     if (exitItem) {
@@ -503,7 +508,7 @@ void CSimpleFrame::OnMenuOpening( wxMenuEvent &event) {
 	if (optionsItem) {
 		optionsItem->Enable(true);
 	}
-    
+
     wxLogTrace(wxT("Function Start/End"), wxT("CAdvancedFrame::OnMenuOpening - Function End"));
 }
 
@@ -528,7 +533,7 @@ void CSimpleFrame::BuildSkinSubmenu( wxMenu *submenu) {
     wxASSERT(wxDynamicCast(pSkinManager, CSkinManager));
 
 
-    // The "Default" skin menu item is localized, but 
+    // The "Default" skin menu item is localized, but
     // the name of the default skin is not localized
     skinItem = submenu->AppendRadioItem(
         ID_SGDEFAULTSKINSELECTOR,
@@ -537,20 +542,20 @@ void CSimpleFrame::BuildSkinSubmenu( wxMenu *submenu) {
 
     astrSkins = pSkinManager->GetCurrentSkins();
     strSelectedSkin = pSkinManager->GetSelectedSkin();
-    
+
     if (strSelectedSkin == pSkinManager->GetDefaultSkinName()) {
         skinItem->Check(true);
     }
-          
+
     // Skins list always contains the Default entry
     if (astrSkins.GetCount() <= 1) {
         skinItem->Check(true);
         skinItem->Enable(false);
         return; // No non-default skins
     }
- 
+
 //    I'd like to put a separator here, but we can't separate radio items
-    
+
     for (i = 0; i < astrSkins.GetCount(); i++) {
         if (astrSkins[i] == pSkinManager->GetDefaultSkinName()) {
             continue;
@@ -574,7 +579,7 @@ void CSimpleFrame::OnSelectDefaultSkin( wxCommandEvent& WXUNUSED(event) ) {
     wxASSERT(pSkinManager);
     wxASSERT(wxDynamicCast(pSkinManager, CSkinManager));
 
-    // The "Default" skin menu item is localized, but 
+    // The "Default" skin menu item is localized, but
     // the name of the default skin is not localized
     pSkinManager->ReloadSkin(pSkinManager->GetDefaultSkinName());
 }
@@ -586,11 +591,11 @@ void CSimpleFrame::OnSelectSkin( wxCommandEvent& event ){
     wxMenuBar *pMenuBar = GetMenuBar();
     int newSkinId = event.GetId();
     int oldSkinID;
-    
+
     wxASSERT(pSkinManager);
     wxASSERT(wxDynamicCast(pSkinManager, CSkinManager));
-    
-    
+
+
     selectedItem = pMenuBar->FindItem(newSkinId);
     if (!selectedItem) return;
 
@@ -599,7 +604,7 @@ void CSimpleFrame::OnSelectSkin( wxCommandEvent& event ){
     if (newSkinName == oldSkinName) return;
 
     if (oldSkinName == pSkinManager->GetDefaultSkinName()) {
-        // The "Default" skin menu item is localized, but 
+        // The "Default" skin menu item is localized, but
         // the name of the default skin is not localized
         oldSkinID = ID_SGDEFAULTSKINSELECTOR;
     } else {
@@ -612,7 +617,7 @@ void CSimpleFrame::OnSelectSkin( wxCommandEvent& event ){
 
     selectedItem->Check(true);
     pSkinManager->ReloadSkin(newSkinName);
-    
+
     wxGetApp().SaveState();
     wxConfigBase::Get(FALSE)->Flush();
 }
@@ -733,7 +738,7 @@ void CSimpleFrame::OnHelp(wxHelpEvent& event) {
 
 void CSimpleFrame::OnReloadSkin(CFrameEvent& WXUNUSED(event)) {
     wxLogTrace(wxT("Function Start/End"), wxT("CSimpleFrame::OnReloadSkin - Function Start"));
-    
+
     CSkinAdvanced*      pSkinAdvanced = wxGetApp().GetSkinManager()->GetAdvanced();
     wxASSERT(pSkinAdvanced);
 
@@ -765,13 +770,13 @@ void CSimpleFrame::OnNotification(CFrameEvent& WXUNUSED(event)) {
 
 void CSimpleFrame::OnRefreshView(CFrameEvent& WXUNUSED(event)) {
     wxLogTrace(wxT("Function Start/End"), wxT("CSimpleFrame::OnRefreshView - Function Start"));
-    
+
     m_pBackgroundPanel->OnFrameRender();
-    
+
     if (dlgMsgsPtr) {
         dlgMsgsPtr->OnRefresh();
     }
-    
+
 #ifdef __WXMAC__
     if (m_iFrameRefreshRate != 1000) {
         m_iFrameRefreshRate = 1000;
@@ -787,7 +792,7 @@ void CSimpleFrame::OnRefreshView(CFrameEvent& WXUNUSED(event)) {
 
 void CSimpleFrame::OnConnect(CFrameEvent& WXUNUSED(event)) {
     wxLogTrace(wxT("Function Start/End"), wxT("CSimpleFrame::OnConnect - Function Begin"));
-    
+
     CMainDocument*     pDoc = wxGetApp().GetDocument();
     CWizardAttach*     pWizard = NULL;
     wxString strComputer = wxEmptyString;
@@ -802,7 +807,9 @@ void CSimpleFrame::OnConnect(CFrameEvent& WXUNUSED(event)) {
     ACCT_MGR_INFO ami;
     PROJECT_INIT_STATUS pis;
 	CC_STATUS     status;
+#ifndef __WXMAC__
     int wasShown = 0;
+#endif
     int wasVisible = 0;
 
     wxASSERT(pDoc);
@@ -827,10 +834,12 @@ void CSimpleFrame::OnConnect(CFrameEvent& WXUNUSED(event)) {
         // Fall through
         //
         // There isn't a need to bring up the attach wizard, the account manager will
-        // take care of ataching to projects when it completes the RPCs
+        // take care of attaching to projects when it completes the RPCs
         //
     } else if (ami.acct_mgr_url.size() && !ami.have_credentials) {
+#ifndef __WXMAC__
         wasShown = IsShown();
+#endif
         Show();
         wasVisible = wxGetApp().IsApplicationVisible();
         if (!wasVisible) {
@@ -844,7 +853,7 @@ void CSimpleFrame::OnConnect(CFrameEvent& WXUNUSED(event)) {
             // are defined for those branded builds on Windows only
 #if defined(_GRIDREPUBLIC) || defined(_PROGRESSTHRUPROCESSORS) || defined(_CHARITYENGINE) || defined(__WXMAC__)
 #ifdef __WXMAC__
-            // For GridRepublic, Charity Engine or ProgressThruProcessors, 
+            // For GridRepublic, Charity Engine or ProgressThruProcessors,
             // the Mac installer put a branding file in our data directory
             long iBrandID = 0;  // 0 is unbranded (default) BOINC
 
@@ -875,7 +884,7 @@ void CSimpleFrame::OnConnect(CFrameEvent& WXUNUSED(event)) {
             bAccountKeyDetected = pis.has_account_key;
             bEmbedded = pis.embedded;
         }
-        
+
         Show();
         wxGetApp().ShowApplication(true);
         pWizard = new CWizardAttach(this);
@@ -917,7 +926,7 @@ void CSimpleFrame::OnEventLog(wxCommandEvent& WXUNUSED(event)) {
 IMPLEMENT_DYNAMIC_CLASS(CSimpleGUIPanel, wxPanel)
 
 BEGIN_EVENT_TABLE(CSimpleGUIPanel, wxPanel)
-    EVT_ERASE_BACKGROUND(CSimpleGUIPanel::OnEraseBackground)    
+    EVT_ERASE_BACKGROUND(CSimpleGUIPanel::OnEraseBackground)
 	EVT_BUTTON(ID_SGNOTICESBUTTON,CSimpleGUIPanel::OnShowNotices)
 	EVT_BUTTON(ID_SGSUSPENDRESUMEBUTTON,CSimpleGUIPanel::OnSuspendResume)
 	EVT_BUTTON(ID_SIMPLE_HELP,CSimpleGUIPanel::OnHelp)
@@ -932,7 +941,7 @@ CSimpleGUIPanel::CSimpleGUIPanel() {
 }
 
 
-CSimpleGUIPanel::CSimpleGUIPanel(wxWindow* parent) : 
+CSimpleGUIPanel::CSimpleGUIPanel(wxWindow* parent) :
     wxPanel(parent, -1, wxDefaultPosition, wxDefaultSize, wxCLIP_CHILDREN | wxBORDER_NONE)
 {
     wxLogTrace(wxT("Function Start/End"), wxT("CSimpleGUIPanel::CSimpleGUIPanel - Overloaded Constructor Function Begin"));
@@ -948,9 +957,9 @@ CSimpleGUIPanel::CSimpleGUIPanel(wxWindow* parent) :
     m_bNewNoticeAlert = false;
     m_bNoticesButtonIsRed = false;
     m_irefreshCount = 0;
-    
+
 	checkForNewNoticesTimer = new wxTimer(this, ID_SIMPLEMESSAGECHECKTIMER);
-	checkForNewNoticesTimer->Start(5000); 
+	checkForNewNoticesTimer->Start(5000);
 
 	dlgOpen = false;
     m_sSuspendString = _("Suspend");
@@ -963,11 +972,11 @@ CSimpleGUIPanel::CSimpleGUIPanel(wxWindow* parent) :
 
     // Box Sizer
     mainSizer = new wxBoxSizer(wxVERTICAL);
-    mainSizer->AddSpacer(ADJUSTFORYDPI(68));
-    mainSizer->Add(m_taskPanel, 1, wxLEFT | wxRIGHT | wxEXPAND, SIDEMARGINS);
-    mainSizer->AddSpacer(ADJUSTFORYDPI(8));
-    mainSizer->Add(m_projPanel, 0, wxLEFT | wxRIGHT | wxEXPAND, SIDEMARGINS);
-    mainSizer->AddSpacer(ADJUSTFORYDPI(8));
+    mainSizer->AddSpacer(68);
+    mainSizer->Add(m_taskPanel, 1, wxLEFT | wxRIGHT | wxEXPAND, sideMargins);
+    mainSizer->AddSpacer(8);
+    mainSizer->Add(m_projPanel, 0, wxLEFT | wxRIGHT | wxEXPAND, sideMargins);
+    mainSizer->AddSpacer(8);
 
 	wxBoxSizer* buttonsSizer;
 	buttonsSizer = new wxBoxSizer( wxHORIZONTAL );
@@ -980,13 +989,13 @@ CSimpleGUIPanel::CSimpleGUIPanel(wxWindow* parent) :
     int suspendWidth, resumeWidth, y;
     GetTextExtent(m_sSuspendString, &suspendWidth, &y);
     GetTextExtent(m_sResumeString, &resumeWidth, &y);
-    
+
     m_bIsSuspended = suspendWidth > resumeWidth;
-    m_SuspendResumeButton = new wxButton( this, ID_SGSUSPENDRESUMEBUTTON, 
+    m_SuspendResumeButton = new wxButton( this, ID_SGSUSPENDRESUMEBUTTON,
                             m_bIsSuspended ? m_sSuspendString : m_sResumeString,
                             wxDefaultPosition, wxDefaultSize, 0 );
     m_SuspendResumeButton->SetToolTip(wxEmptyString);
-    
+
 	buttonsSizer->Add( m_SuspendResumeButton, 0, wxEXPAND, 0 );
     buttonsSizer->AddStretchSpacer();
 
@@ -997,15 +1006,13 @@ CSimpleGUIPanel::CSimpleGUIPanel(wxWindow* parent) :
     helpTip.Printf(_("Get help with %s"), pSkinAdvanced->GetApplicationShortName().c_str());
     m_HelpButton->SetToolTip(helpTip);
 
-	mainSizer->Add( buttonsSizer, 0, wxLEFT | wxRIGHT | wxEXPAND, 2 * SIDEMARGINS );
-    mainSizer->AddSpacer(ADJUSTFORYDPI(10));
+	mainSizer->Add( buttonsSizer, 0, wxLEFT | wxRIGHT | wxEXPAND, 2 * sideMargins);
+    mainSizer->AddSpacer(10);
 
-	SetSizer(mainSizer);
     Layout();
-    
-    mainSizer->Fit(GetParent());
+    SetSizerAndFit(mainSizer);
 
-    SetBackgroundBitmap();   
+    SetBackgroundBitmap();
 
 #ifdef __WXMAC__
     if (compareOSVersionTo(10, 7) >= 0) {
@@ -1013,7 +1020,7 @@ CSimpleGUIPanel::CSimpleGUIPanel(wxWindow* parent) :
     } else {
         m_iRedRingRadius = 12;
     }
-#endif    
+#endif
 
     m_SuspendResumeButton->Disable();
 
@@ -1026,11 +1033,11 @@ CSimpleGUIPanel::CSimpleGUIPanel(wxWindow* parent) :
 CSimpleGUIPanel::~CSimpleGUIPanel()
 {
     wxLogTrace(wxT("Function Start/End"), wxT("CSimpleGUIPanel::CSimpleGUIPanel - Destructor Function Begin"));
-    
+
     checkForNewNoticesTimer->Stop();
 	delete checkForNewNoticesTimer;
     m_bmpBg = wxNullBitmap; // Deletes old bitmap via reference counting
-    
+
     wxLogTrace(wxT("Function Start/End"), wxT("CSimpleGUIPanel::CSimpleGUIPanel - Destructor Function End"));
 }
 
@@ -1144,7 +1151,7 @@ void CSimpleGUIPanel::ReskinInterface() {
 
 void CSimpleGUIPanel::OnProjectsAttachToProject(wxCommandEvent& event) {
     wxLogTrace(wxT("Function Start/End"), wxT("CSimpleGUIPanel::OnProjectsAttachToProject - Function Begin"));
-	
+
     CSimpleFrame* pFrame = wxDynamicCast(GetParent(), CSimpleFrame);
     wxASSERT(pFrame);
 
@@ -1161,9 +1168,9 @@ void CSimpleGUIPanel::OnFrameRender() {
 	CC_STATUS           status;
     bool                isSuspended;
 
-    // OnFrameRender() may be called while SimpleGUI initialization is 
-    // in progress due to completion of a periodic get_messages RPC, 
-    // causing unintended recursion in CMainDocument::RequestRPC().  
+    // OnFrameRender() may be called while SimpleGUI initialization is
+    // in progress due to completion of a periodic get_messages RPC,
+    // causing unintended recursion in CMainDocument::RequestRPC().
     // Check for that situation here.
     if (pDoc->WaitingForRPC()) return;
 
@@ -1173,7 +1180,7 @@ void CSimpleGUIPanel::OnFrameRender() {
         m_taskPanel->UpdatePanel(true);
         return;
     }
-	
+
     if (workCount != m_oldWorkCount) {
         if (workCount < 0) {
             m_projPanel->Hide();
@@ -1183,10 +1190,10 @@ void CSimpleGUIPanel::OnFrameRender() {
         this->Layout();
         ReskinInterface();
     }
-    
+
     if (IsShown()) {
 	    if ( pDoc->IsConnected() ) {
-        
+
             // Show Resume or Suspend as appropriate
             pDoc->GetCoreClientStatus(status);
 
@@ -1217,9 +1224,9 @@ void CSimpleGUIPanel::OnFrameRender() {
         if ( dlgOpen ) {
             return;
         }
-        
+
         m_oldWorkCount = workCount;
-        
+
         m_taskPanel->UpdatePanel(false);
     }
 }
@@ -1262,9 +1269,9 @@ void CSimpleGUIPanel::OnShowNotices(wxCommandEvent& /*event*/) {
 
 	CDlgMessages dlg(GetParent());
     SetDlgOpen(true);
-    
+
     ((CSimpleFrame*)GetParent())->SetMsgsDlgOpen(&dlg);
-    
+
     dlg.ShowModal();
 
     SetDlgOpen(false);
@@ -1281,7 +1288,7 @@ void CSimpleGUIPanel::OnSuspendResume(wxCommandEvent& /*event*/) {
 
     if (m_bIsSuspended) {
         pDoc->GetCoreClientStatus(ccs);
-        
+
         if ((RUN_MODE_NEVER == ccs.task_mode) && (0 >= ccs.task_mode_delay)) {
             pDoc->SetActivityRunMode(RUN_MODE_AUTO, 0);
         } else {
@@ -1290,7 +1297,7 @@ void CSimpleGUIPanel::OnSuspendResume(wxCommandEvent& /*event*/) {
     } else {
         pDoc->SetActivityRunMode(RUN_MODE_NEVER, 3600);
     }
-    
+
     m_SuspendResumeButton->SetLabel(m_bIsSuspended ? m_sResumeString : m_sSuspendString);
     m_SuspendResumeButton->SetToolTip(m_bIsSuspended ? m_sResumeButtonToolTip : m_sSuspendButtonToolTip);
 }
@@ -1307,12 +1314,12 @@ void CSimpleGUIPanel::OnHelp(wxCommandEvent& WXUNUSED(event)) {
         wxT("%s?target=simple&version=%s&controlid=%d"),
         strURL.c_str(),
         wxString(BOINC_VERSION_STRING, wxConvUTF8).c_str(),
-        ID_SIMPLE_HELP        
+        ID_SIMPLE_HELP
 
     );
 
     wxLaunchDefaultBrowser(wxurl);
-        
+
     wxLogTrace(wxT("Function Start/End"), wxT("CSimpleGUIPanel::OnHelp - Function End"));
 }
 
@@ -1341,7 +1348,7 @@ void CSimpleGUIPanel::OnPaint(wxPaintEvent& WXUNUSED(event)) {
             r.Inflate(3, 3);
             myDC.DrawRoundedRectangle(r.x, r.y, r.width, r.height, 6);
 #endif
-            // Restore Mode, Pen and Brush 
+            // Restore Mode, Pen and Brush
             myDC.SetBackgroundMode(oldMode);
             myDC.SetPen(oldPen);
             myDC.SetBrush(oldBrush);
@@ -1350,11 +1357,11 @@ void CSimpleGUIPanel::OnPaint(wxPaintEvent& WXUNUSED(event)) {
 }
 
 
-// We don't reliably get EraseBackground events under Linux, 
+// We don't reliably get EraseBackground events under Linux,
 // so there is a workaround at CSimplePanelBase::MakeBGBitMap()
 void CSimpleGUIPanel::OnEraseBackground(wxEraseEvent& event) {
     wxDC *dc = event.GetDC();
-    
+
 #ifdef __WXMAC__
     // Avoid unnecessary drawing due to Mac progress indicator's animation
     wxRect clipRect;
