@@ -1,6 +1,6 @@
 // This file is part of BOINC.
 // http://boinc.berkeley.edu
-// Copyright (C) 2020 University of California
+// Copyright (C) 2022 University of California
 //
 // BOINC is free software; you can redistribute it and/or modify it
 // under the terms of the GNU Lesser General Public License
@@ -317,7 +317,7 @@ CScreensaver::CScreensaver() {
     m_iGraphicsStartingMsgCounter = 0;
     saverState = SaverState_Idle;
     m_wasAlreadyRunning = false;
-    m_CoreClientPID = nil;
+    m_CoreClientPID = 0;
     setSSMessageText(0);
     m_CurrentBannerMessage = 0;
     m_bQuitDataManagementProc = false;
@@ -331,15 +331,13 @@ CScreensaver::CScreensaver() {
     m_gfx_Cleanup_IPC = NULL;
     safe_strcpy(passwd_buf, "");
    
-    if (gIsCatalina) {
-        getcwd(saved_dir, sizeof(saved_dir));
-        chdir("/Library/Application Support/BOINC Data");
-        read_gui_rpc_password(passwd_buf, msg);
-        chdir(saved_dir);
-        
-        CFStringRef cf_gUserName = SCDynamicStoreCopyConsoleUser(NULL, NULL, NULL);
-        CFStringGetCString(cf_gUserName, gUserName, sizeof(gUserName), kCFStringEncodingUTF8);
-    }
+    getcwd(saved_dir, sizeof(saved_dir));
+    chdir("/Library/Application Support/BOINC Data");
+    read_gui_rpc_password(passwd_buf, msg);
+    chdir(saved_dir);
+    
+    CFStringRef cf_gUserName = SCDynamicStoreCopyConsoleUser(NULL, NULL, NULL);
+    CFStringGetCString(cf_gUserName, gUserName, sizeof(gUserName), kCFStringEncodingUTF8);
     
     // Get project-defined default values for GFXDefaultPeriod, GFXSciencePeriod, GFXChangePeriod
     GetDefaultDisplayPeriods(periods);
@@ -361,9 +359,7 @@ CScreensaver::CScreensaver() {
 
 
 int CScreensaver::Create() {
-    OSStatus err;
-    
-    // Ugly workaround for a problem with the System Preferences app
+        // Ugly workaround for a problem with the System Preferences app
     // For an unknown reason, when this screensaver is run using the 
     // Test button in the System Prefs Screensaver control panel, the 
     // control panel calls our stopAnimation function as soon as the 
@@ -382,8 +378,8 @@ int CScreensaver::Create() {
 
     // Calculate the estimated blank time by adding the starting
     //  time and and the user-specified time which is in minutes
-    // On dual-GPU Macbok Pros, the CScreensaver class will be
-    // constructed and destructed each time we switch beteen
+    // On dual-GPU Macbook Pros, the CScreensaver class will be
+    // constructed and destructed each time we switch between
     // battery and AC power, so we need to get the starting time
     // only once.
     if (!ScreenSaverStartTime) {
@@ -406,15 +402,13 @@ int CScreensaver::Create() {
         strlcat(m_gfx_Switcher_Path, "/gfx_switcher", sizeof(m_gfx_Switcher_Path));
         strlcat(m_gfx_Cleanup_Path, "/gfx_cleanup\"", sizeof(m_gfx_Switcher_Path));
 
-        if (gIsCatalina) {
-            // Launch helper app to work around a bug in OS 10.15 Catalina to
-            // kill current graphics app if ScreensaverEngine exits without 
-            // first calling [ScreenSaverView stopAnimation]
-            //TODO: Should we use this on OS 10.13+ ?
-            m_gfx_Cleanup_IPC = popen(m_gfx_Cleanup_Path, "w");
-        }
+        // Launch helper app to work around a bug in OS 10.15 Catalina to
+        // kill current graphics app if ScreensaverEngine exits without 
+        // first calling [ScreenSaverView stopAnimation]
+        //TODO: Should we use this on OS 10.13+ ?
+        m_gfx_Cleanup_IPC = popen(m_gfx_Cleanup_Path, "w");
         
-        err = initBOINCApp();
+        initBOINCApp();
 
         CGDisplayHideCursor(kCGNullDirectDisplay);
     
@@ -442,11 +436,6 @@ int CScreensaver::Create() {
 
 
 OSStatus CScreensaver::initBOINCApp() {
-    char boincPath[2048];
-    pid_t myPid;
-    int status;
-    OSStatus err;
-
     saverState = SaverState_CantLaunchCoreClient;
     
     m_CoreClientPID = getClientPID();
@@ -459,56 +448,7 @@ OSStatus CScreensaver::initBOINCApp() {
     
     m_wasAlreadyRunning = false;
     
-    if (gIsCatalina) {
-        return noErr;   // Screensavers can't launch setuid /setgid processes as of Catalina
-    }
-    if (++retryCount > 3)   // Limit to 3 relaunches to prevent thrashing
-        return -1;
-
-    // Find boinc client within BOINCManager.app
-    // First, try default path
-    strcpy(boincPath, appPath[brandId]);
-    strcat(boincPath, "/Contents/Resources/boinc");
-
-    // If not at default path, search for it by creator code and bundle identifier
-    if (!boinc_file_exists(boincPath)) {
-        err = GetPathToAppFromID('BNC!', CFSTR("edu.berkeley.boinc"),  boincPath, sizeof(boincPath));
-        if (err) {
-            saverState = SaverState_CantLaunchCoreClient;
-            return err;
-        } else {
-            strcat(boincPath, "/Contents/Resources/boinc");
-        }
-    }
-
-    if ( (myPid = fork()) < 0)
-        return -1;
-    else if (myPid == 0)			// child
-    {
-      // We don't customize BOINC Data directory name for branding
-#if 0   // Code for separate data in each user's private directory
-        char buf[256];
-        safe_strcpy(buf, getenv("HOME"));
-        safe_strcat(buf, "/Library/Application Support/BOINC Data");
-        status = chdir(buf);
-#else   // All users share the same data
-        status = chdir("/Library/Application Support/BOINC Data");
-#endif
-        if (status) {
-            perror("chdir");
-            fflush(NULL);
-            _exit(status);
-        }
-
-        status = execl(boincPath, boincPath, "-redirectio", "-saver", (char *) 0);
-        fflush(NULL);
-        _exit(127);         // execl error (execl should never return)
-    } else {
-        m_CoreClientPID = myPid;		// make this available globally
-        saverState = SaverState_LaunchingCoreClient;
-    }
-
-    return noErr;
+    return noErr;   // Screensavers can't launch setuid /setgid processes as of Catalina
 }
 
 
@@ -519,7 +459,6 @@ int CScreensaver::getSSMessage(char **theMessage, int* coveredFreq) {
     *coveredFreq = 0;
     pid_t myPid;
     CC_STATE ccstate;
-    OSStatus err;
     
     if (ScreenIsBlanked) {
         setSSMessageText(0);   // No text message
@@ -531,7 +470,7 @@ int CScreensaver::getSSMessage(char **theMessage, int* coveredFreq) {
     
     switch (saverState) {
     case SaverState_RelaunchCoreClient:
-        err = initBOINCApp();
+        initBOINCApp();
         break;
     
     case  SaverState_LaunchingCoreClient:
@@ -575,15 +514,7 @@ int CScreensaver::getSSMessage(char **theMessage, int* coveredFreq) {
             CreateDataManagementThread();
             // ToDo: Add a timeout after which we display error message
         } else {
-            if (gIsCatalina) {
-                return noErr;   // Screensavers can't launch setuid /setgid processes as of Catalina
-            }
-            // Take care of the possible race condition where the Core Client was in the  
-            // process of shutting down just as ScreenSaver started, so initBOINCApp() 
-            // found it already running but now it has shut down.
-            if (m_wasAlreadyRunning) { // If we launched it, then just wait for it to start
-                saverState = SaverState_RelaunchCoreClient;
-            }
+            return noErr;   // Screensavers can't launch setuid /setgid processes as of Catalina
         }
          break;
 
@@ -691,16 +622,7 @@ int CScreensaver::getSSMessage(char **theMessage, int* coveredFreq) {
             break;
         }
         
-        if (gIsCatalina) {
-            setSSMessageText(CCNotRunningMsg);
-            break;
-        } else {
-            setSSMessageText(CantLaunchCCMsg);
-        }
-        
-        // Set up a separate thread for running screensaver graphics 
-        // even if we can't communicate with core client
-        CreateDataManagementThread();
+        setSSMessageText(CCNotRunningMsg);
         break;
 
     case SaverState_Idle:
@@ -779,8 +701,6 @@ void * CScreensaver::DataManagementProcStub(void* param) {
 
 
 void CScreensaver::HandleRPCError() {
-    static time_t last_RPC_retry = 0;
-    time_t now = time(0);
     int retval;
    
     // Attempt to restart BOINC Client if needed, reinitialize the RPC client and state
@@ -788,23 +708,7 @@ void CScreensaver::HandleRPCError() {
     m_bConnected = false;
     
     if (saverState == SaverState_CantLaunchCoreClient) {
-        if (gIsCatalina) {
-            return;   // Screensavers can't launch setuid /setgid processes as of Catalina
-        }
-        if ((now - last_RPC_retry) < RPC_RETRY_INTERVAL) {
-            return;
-        }
-        last_RPC_retry = now;
-    } else {
-        // There is a possible race condition where the Core Client was in the  
-        // process of shutting down just as ScreenSaver started, so initBOINCApp() 
-        // found it already running but now it has shut down.  This code takes 
-        // care of that and other situations where the Core Client quits unexpectedy.  
-        // Code in initBOINC_App() limits # launch retries to 3 to prevent thrashing.
-        if (getClientPID() == 0) {
-            saverState = SaverState_RelaunchCoreClient;
-            m_bResetCoreState = true;
-         }
+        return;   // Screensavers can't launch setuid /setgid processes as of Catalina
     }
     
     // If Core Client is hung, it might cause RPCs to hang, preventing us from 
