@@ -128,12 +128,18 @@ int make_secure_random_string_os(char* out) {
     HCRYPTPROV hCryptProv;
         
     if(! CryptAcquireContext(&hCryptProv, NULL, NULL, PROV_RSA_FULL, 0)) {
-        return -1;
+        if (GetLastError() == NTE_BAD_KEYSET) {
+            if (!CryptAcquireContext(&hCryptProv, NULL, NULL, PROV_RSA_FULL, CRYPT_NEWKEYSET)) {
+                return -1;
+            }
+        } else {
+            return -2;
+        }
     }
     
     if(! CryptGenRandom(hCryptProv, (DWORD) 32, (BYTE *) buf)) {
         CryptReleaseContext(hCryptProv, 0);
-        return -1;
+        return -3;
     }
         
     CryptReleaseContext(hCryptProv, 0);
@@ -150,7 +156,7 @@ int make_secure_random_string_os(char* out) {
     }
     size_t n = fread(buf, 32, 1, f);
     fclose(f);
-    if (n != 1) return -1;
+    if (n != 1) return -2;
 #endif
     md5_block((const unsigned char*)buf, 32, out);
     return 0;
